@@ -1,3 +1,4 @@
+use std::fmt::Debug;
 
 use crate::resp_error::RespError;
 
@@ -5,11 +6,31 @@ mod serde;
 mod to_response;
 mod try_op;
 
+pub use to_response::Nil;
+
 pub enum RespResult<T, E> {
     Success(T),
     Err(E),
 }
 
+impl<T: std::fmt::Debug, E: RespError> Debug for RespResult<T, E> {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        match self {
+            Self::Success(arg0) => f.debug_tuple("Success").field(arg0).finish(),
+            Self::Err(arg0) => f.debug_tuple("Err").field(&arg0.description()).finish(),
+        }
+    }
+}
+
+impl<T: std::fmt::Display, E: RespError> std::fmt::Display for RespResult<T, E> {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        match self {
+            RespResult::Success(data) => write!(f, "RespResult Ok[{}]", data),
+            RespResult::Err(err) => write!(f, "RespResult Err[{}]", err.description()),
+        }
+    }
+}
+
 impl<T, E> RespResult<T, E> {
     #[inline]
     pub fn map<N, F>(self, f: F) -> RespResult<N, E>
@@ -48,7 +69,7 @@ impl<T, E> RespResult<T, E> {
     #[inline]
     pub fn and_then<N, F>(self, f: F) -> RespResult<N, E>
     where
-        F: FnOnce(T) -> RespResult<N,E>,
+        F: FnOnce(T) -> RespResult<N, E>,
     {
         match self {
             RespResult::Success(data) => f(data),
@@ -59,7 +80,7 @@ impl<T, E> RespResult<T, E> {
     #[inline]
     pub fn or_else<N, F>(self, f: F) -> RespResult<T, N>
     where
-        F: FnOnce(E) -> RespResult<T,N>,
+        F: FnOnce(E) -> RespResult<T, N>,
     {
         match self {
             RespResult::Success(data) => RespResult::Success(data),
