@@ -1,5 +1,4 @@
-
-
+use std::convert::Infallible;
 #[allow(unused_imports)]
 use std::str::FromStr;
 
@@ -11,7 +10,7 @@ use super::RespResult;
 #[allow(dead_code)]
 #[inline]
 fn prepare_respond<T, E>(
-    r: RespResult<T, E>,
+    r: &RespResult<T, E>,
 ) -> Result<(Vec<u8>, StatusCode, Option<(HeaderName, HeaderValue)>), serde_json::Error>
 where
     T: serde::Serialize,
@@ -20,7 +19,7 @@ where
     #[allow(unused_variables)]
     let cfg = &get_config().resp;
 
-    let vec = serde_json::to_vec(&r);
+    let vec = serde_json::to_vec(r);
     let body = match vec {
         Ok(body) => body,
         Err(e) => {
@@ -49,7 +48,7 @@ where
     };
     #[cfg(feature = "extra-code")]
     let r_header = {
-        match &r {
+        match r {
             RespResult::Success(_) => None,
             RespResult::Err(e) => {
                 if let Some(n) = cfg.extra_code {
@@ -75,9 +74,9 @@ where
     );
     Ok((body, status, r_header))
 }
-
+#[cfg(feature = "mime")]
 #[allow(dead_code)]
-static JSON_TYPE: &str = "application/json";
+static JSON_TYPE: &'static mime::Mime = &mime::APPLICATION_JSON;
 
 #[cfg(feature = "for-axum")]
 impl<T, E> axum::response::IntoResponse for RespResult<T, E>
@@ -87,15 +86,15 @@ where
 {
     #[inline]
     fn into_response(self) -> axum::response::Response {
-        match prepare_respond(self) {
+        match prepare_respond(&self) {
             Ok((body, status, eh)) => match eh {
                 None => axum::response::Response::builder()
                     .status(status)
-                    .header(http::header::CONTENT_TYPE, JSON_TYPE)
+                    .header(http::header::CONTENT_TYPE, JSON_TYPE.as_ref())
                     .body(axum::body::boxed(axum::body::Full::from(body))),
                 Some((k, v)) => axum::response::Response::builder()
                     .status(status)
-                    .header(http::header::CONTENT_TYPE, JSON_TYPE)
+                    .header(http::header::CONTENT_TYPE, JSON_TYPE.as_ref())
                     .header(k, v)
                     .body(axum::body::boxed(axum::body::Full::from(body))),
             },
@@ -114,21 +113,70 @@ where
     E: RespError,
 {
     type Body = actix_web::body::BoxBody;
-    
+
     #[inline]
     fn respond_to(self, _req: &actix_web::HttpRequest) -> actix_web::HttpResponse<Self::Body> {
-        match prepare_respond(self) {
-            Ok((body, status, eh)) => match eh {
-                None => actix_web::HttpResponse::build(status)
-                    .content_type(JSON_TYPE)
-                    .body(body),
-                Some((k, v)) => actix_web::HttpResponse::build(status)
-                    .content_type(JSON_TYPE)
-                    .insert_header((k, v))
-                    .body(body),
-            },
-            Err(e) => actix_web::HttpResponse::build(StatusCode::INTERNAL_SERVER_ERROR)
-                .body(e.to_string()),
+        to_actix_resp(&self)
+    }
+}
+
+#[derive(Debug, serde::Serialize)]
+pub struct Nil;
+
+impl From<()> for Nil {
+    fn from(_: ()) -> Self {
+        Self
+    }
+}
+
+impl From<Infallible> for Nil {
+    fn from(_: Infallible) -> Self {
+        Self
+    }
+}
+
+impl std::fmt::Display for Nil {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        write!(f, "Nil")
+    }
+}
+
+#[cfg(feature = "for-actix")]
+impl<E> actix_web::ResponseError for RespResult<Nil, E>
+where
+    E: RespError,
+{
+    fn status_code(&self) -> StatusCode {
+        match self {
+            RespResult::Err(e) => e.http_code(),
+            RespResult::Success(_) => StatusCode::OK,
+        }
+    }
+
+    fn error_response(&self) -> actix_web::HttpResponse<actix_web::body::BoxBody> {
+        to_actix_resp(self)
+    }
+}
+
+#[cfg(feature = "for-actix")]
+fn to_actix_resp<T, E>(this: &RespResult<T, E>) -> actix_web::HttpResponse
+where
+    T: serde::Serialize,
+    E: RespError,
+{
+    match prepare_respond(this) {
+        Ok((body, status, Some(e_header))) => actix_web::HttpResponse::build(status)
+            .content_type(JSON_TYPE.as_ref())
+            .insert_header(e_header)
+            .body(body),
+        Ok((body, status, None)) => actix_web::HttpResponse::build(status)
+            .content_type(JSON_TYPE.as_ref())
+            .body(body),
+        Err(err) => {
+            let body = format!(r#"{{"panic-error":"序列化响应体失败","err-msg":{}}}"#, err);
+            actix_web::HttpResponse::InternalServerError()
+                .content_type(JSON_TYPE.as_ref())
+                .body(body)
         }
     }
 }
